tests.models.output package — django_analyses 0.0.3 documentation

# tests.models.output package

## Subpackages

- tests.models.output.definitions package
  - Submodules
  - tests.models.output.definitions.test_file_output_definition module
  - tests.models.output.definitions.test_float_output_definition module
  - tests.models.output.definitions.test_output_definition module
  - Module contents
- tests.models.output.types package
  - Submodules
  - tests.models.output.types.test_file_output module
  - tests.models.output.types.test_float_output module
  - Module contents

## Submodules

## tests.models.output.test_output_specification module

class `tests.models.output.test_output_specification.` `OutputSpecificationTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `OutputSpecification` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_output_definitions_property_return_type`()
  `test_output_definitions_property_returns_subclasses`()
  `test_string`()

## Module contents